@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.4.4
+ * Version: 0.5.0
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -175,7 +175,7 @@ var splitInner = function(left, regex) {
 };
 
 var Regexps = {
-	whitespace: /((?:\W|,).*)/,
+	whitespace: /((?:\s|,).*)/,
 	doubleSquare: /\]\](.*)/,
 	doubleQuote: /"(.*)/
 };
@@ -630,6 +630,57 @@ Tiddlers.fn = {
 			});
 		}
 	},
+	// ord is, e.g. "tags, -title" (sorts by tags asc, then by title desc), or a function (defaults to Array.prototype.sort)
+	sort: function(ord) {
+		var sortOrder = (typeof ord === 'string') ? ord.split(/,\s*/) : null,
+			_sort = Array.prototype.sort;
+
+		if (sortOrder) {
+			return _sort.call(this, function(left, right) {
+				var result = 0;
+				$.each(sortOrder, function(i, field) {
+					var desc = (field.charAt(0) === '-') ? true : false,
+						name = (desc) ? field.slice(1) : field,
+						leftVal = left[name] ||
+							(left.fields && left.fields[name]) || null,
+						rightVal = right[name] ||
+							(right.fields && right.fields[name]) || null;
+
+					if (typeof leftVal === 'string') {
+						leftVal = leftVal.toLowerCase();
+					}
+					if (typeof rightVal === 'string') {
+						rightVal = rightVal.toLowerCase();
+					}
+
+					if (desc) {
+						result = (leftVal > rightVal) ? -1 :
+							((leftVal < rightVal) ? 1 : null);
+					} else {
+						result = (leftVal > rightVal) ? 1 :
+							((leftVal < rightVal) ? -1 : null);
+					}
+
+					if (result) {
+						return false;
+					}
+				});
+
+				return result;
+			});
+		} else {
+			return _sort.call(this, ord);
+		}
+	},
+	// return the first n tiddlers in the list
+	limit: function(n) {
+		var newList = Tiddlers(this.store),
+			i, l;
+		for (i = 0, l = this.length; i < n && i < l; i++) {
+			newList.push(this[i]);
+		}
+		return newList;
+	},
 	each: function(fn) {
 		var self = this;
 		$.each(self, function(i, tiddler) {
@@ -1183,6 +1234,14 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 
 	// public functions
 
+	// add the filter constructor in case people want to make collections manually
+	self.Collection = (function() {
+		return function() {
+			var args = Array.prototype.slice.call(arguments);
+			args.unshift(self);
+			return filter.apply(self, args);
+		};
+	}());
 	// let filter be extensible
 	self.fn = filter.fn;
 
